@@ -262,6 +262,111 @@ class PythonAnalyzer(Analyzer, cst.CSTVisitor):
 
     def analyze_function(self, node: cst.FunctionDef) -> None:
         self._check_super_call(node)
+        self._check_depends(node)
+
+    def _check_depends(self, node: cst.FunctionDef) -> None:
+        if not self._class_metadata:
+            return
+        Model = self._class_metadata._model
+        if not Model:
+            return
+        pool = self._class_metadata._pool
+        from trytond.model.fields import Many2One
+
+        for decorator in node.decorators:
+            if not m.matches(decorator, m.Decorator(
+                        decorator=m.Call(func=m.Attribute(value=m.Name(value='fields'),
+                                attr=m.Name(value='depends'))))):
+                continue
+            for arg in decorator.decorator.args:
+                if m.matches(arg, m.Arg(value=m.SimpleString(), keyword=None)):
+                    cur_model = Model
+                    field_names = arg.value.value[1:-1].split('.')
+                    for field_name in field_names[:-1]:
+                        if not field_name.startswith('_parent_'):
+                            # TODO: dedicated diagnostic
+                            self.add_diagnostic(
+                                UnknownAttribute.init_from_analyzer(
+                                    self,
+                                    arg.value,
+                                    model_name=cur_model.__name__,
+                                    attr_name=field_name,
+                                    )
+                                )
+                            break
+                        field_name = field_name[8:]
+                        if field_name not in cur_model._fields:
+                            # TODO: dedicated diagnostic
+                            self.add_diagnostic(
+                                UnknownAttribute.init_from_analyzer(
+                                    self,
+                                    arg.value,
+                                    model_name=cur_model.__name__,
+                                    attr_name=field_name,
+                                    )
+                                )
+                            break
+                        field = cur_model._fields[field_name]
+                        if not isinstance(field, Many2One):
+                            # TODO: dedicated diagnostic
+                            self.add_diagnostic(
+                                UnknownAttribute.init_from_analyzer(
+                                    self,
+                                    arg.value,
+                                    model_name=cur_model.__name__,
+                                    attr_name=field_name,
+                                    )
+                                )
+                            break
+                        try:
+                            cur_model = pool.get(field.model_name, 'model')
+                        except KeyError:
+                            self.add_diagnostic(
+                                UnknownModel.init_from_analyzer(
+                                    self,
+                                    arg.value,
+                                    unknown_name=field.model_name,
+                                )
+                            )
+                            break
+                    else:
+                        field_name = field_names[-1]
+                        if field_name not in cur_model._fields:
+                            self.add_diagnostic(
+                                UnknownAttribute.init_from_analyzer(
+                                    self,
+                                    arg.value,
+                                    model_name=cur_model.__name__,
+                                    attr_name=field_name,
+                                    )
+                                )
+                elif m.matches(arg, m.Arg(value=m.List(),
+                            keyword=m.Name())):
+                    if arg.keyword.value != 'methods':
+                        # TODO: dedicated diagnostic
+                        self.add_diagnostic(
+                            UnknownAttribute.init_from_analyzer(
+                                self,
+                                arg.value,
+                                model_name=cur_model.__name__,
+                                attr_name=field_name,
+                                )
+                            )
+                        continue
+                    for method in arg.value.elements:
+                        if not m.matches(method,
+                                m.Element(value=m.SimpleString())):
+                            continue
+                        method_name = method.value.value[1:-1]
+                        if method_name not in dir(Model):
+                            self.add_diagnostic(
+                                UnknownAttribute.init_from_analyzer(
+                                    self,
+                                    arg.value,
+                                    model_name=Model.__name__,
+                                    attr_name=method_name,
+                                    )
+                                )
 
     def _check_super_call(self, node: cst.FunctionDef) -> None:
         super_call = m.extractall(
